@@ -1,7 +1,7 @@
 import os
 
 from .version import _warn_if_setuptools_outdated
-from .utils import trace, do
+from .utils import do
 from .discover import find_matching_entrypoint
 from . import get_version
 
@@ -14,10 +14,7 @@ def version_keyword(dist, keyword, value):
         value = {}
     if getattr(value, '__call__', None):
         value = value()
-    try:
-        dist.metadata.version = get_version(**value)
-    except Exception as e:
-        trace('error', e)
+    dist.metadata.version = get_version(**value)
 
 
 def find_files(path='.'):
